<?php
namespace CADSUP\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\Util\QuerySelector;

class FornecedorNaoAtendeController extends \Teknisa\GER\Controllers\TeknisaCrud 
{

    protected $dataSourceName = "fornecedornaoatende";
	protected $connection;

	public function __construct($crudService, ParameterBag $parameterBag, $connection) 
	{
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->con = $connection;
    }
    
    private function verifyFornecedorAtendeFilial($rows)
    {
    	$connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$queryorcl = "SELECT COUNT(1) CONTADOR
					FROM FILIAL 
				   WHERE (FILIAL.CDREGIAO = :P_CDREGIAO)
				     AND ((EXISTS (SELECT CDFORNECED 
				    				 FROM REFORFIL 
				    				WHERE REFORFIL.CDFORNECED = :P_CDFORNECED
				    				  AND REFORFIL.CDFILIAL   = FILIAL.CDFILIAL
				    				  AND REFORFIL.CDPERIENTR IS NOT NULL)) OR 
				    	 (NOT EXISTS (SELECT CDFORNECED 
				    					FROM REFORFIL
				    				   WHERE REFORFIL.CDFORNECED = :P_CDFORNECED
				    				     AND REFORFIL.CDFILIAL   = FILIAL.CDFILIAL)))";
		$querypost = "SELECT COUNT(1) AS CONTADOR FROM FILIAL WHERE FILIAL.CDREGIAO = :P_CDREGIAO AND ( (EXISTS ( SELECT CDFORNECED FROM REFORFIL WHERE REFORFIL.CDFORNECED = :P_CDFORNECED AND REFORFIL.CDFILIAL = FILIAL.CDFILIAL AND REFORFIL.CDPERIENTR IS NOT NULL )) OR (NOT EXISTS ( SELECT CDFORNECED FROM REFORFIL WHERE REFORFIL.CDFORNECED = :P_CDFORNECED AND REFORFIL.CDFILIAL = FILIAL.CDFILIAL )) );";
		$arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		$stmt = $this->con->prepare($query);
		$stmt->execute(array(
			"P_CDREGIAO" => $rows[0]['CDREGIAO'],
			"P_CDFORNECED" => $rows[0]['CDFORNECED']
		));
		
		return $stmt->fetchAll();
    }
    
    private function verifyFornecedorCadastrado($rows)
    {
    	$connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$queryorcl = "SELECT COUNT(1) CONTADOR
					FROM REFOREG
				   WHERE CDREGIAO	= :P_CDREGIAO
				     AND CDFORNECED = :P_CDFORNECED";
		$querypost = "SELECT COUNT(1) AS CONTADOR FROM REFOREG WHERE CDREGIAO = :P_CDREGIAO AND CDFORNECED = :P_CDFORNECED;";		     
		$arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		$stmt = $this->con->prepare($query);
		$stmt->execute(array(
			"P_CDREGIAO" => $rows[0]['CDREGIAO'],
			"P_CDFORNECED" => $rows[0]['CDFORNECED']
		));
		
		return $stmt->fetchAll();
    }
	
	public function save(DTO\Request $request, DTO\Response $response)
	{
		$connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
		$rows = $request->getDataSet()->getRows();
		$fornecedorNaoAtendeFilial = $this->verifyFornecedorAtendeFilial($rows);
		$fornecedorJaCadastrado = $this->verifyFornecedorCadastrado($rows);
		if($fornecedorNaoAtendeFilial[0]['CONTADOR'] > 0 ){
			$response->setError(new Error("fornecedorNaoAtendeFilial", 500));
		} else if($fornecedorJaCadastrado[0]['CONTADOR'] > 0 ){
			$response->setError(new Error("fornecedorJaCadastrado", 500));
		} else {
			try {
				$queryorcl = 'INSERT INTO REFOREG (CDREGIAO, CDFORNECED) VALUES (:CDREGIAO, :CDFORNECED)';
				$querypost = 'INSERT INTO REFOREG (CDREGIAO, CDFORNECED) VALUES (:CDREGIAO, :CDFORNECED);';
				$arrayQueries = array (
            		'default'   => $queryorcl,
            		'pdo_pgsql' => $querypost
    			 );
        		$query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
				$stmt = $this->con->prepare($query);
				$stmt->execute(array(
					"CDREGIAO" => $request->getDataSet()->getRows()[0]['CDREGIAO'],
					"CDFORNECED" => $request->getDataSet()->getRows()[0]['CDFORNECED']
				));
			} catch (\Exception $e) {
				$response->setError(new Error($e->getMessage(), 500));
			}
		}
	}
	
	public function delete(DTO\Request $request, DTO\Response $response)
	{
		$connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
		$row = $request->getRow();
		try {
			$queryorcl = "DELETE FROM REFOREG WHERE CDREGIAO = :CDREGIAO AND CDFORNECED = :CDFORNECED";
			$querypost = "DELETE FROM REFOREG WHERE CDREGIAO = :CDREGIAO AND CDFORNECED = :CDFORNECED;";
			$arrayQueries = array (
            		'default'   => $queryorcl,
            		'pdo_pgsql' => $querypost
    			 );
        	$query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
			$stmt = $this->con->prepare($query);
			$stmt->execute(array(
				"CDREGIAO" => $request->getRow()['CDREGIAO'],
				"CDFORNECED" => $request->getRow()['CDFORNECED']
			));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
}